@@ -5,12 +5,19 @@ from typing import Optional, Literal
 
 import fire  # type: ignore
 from mcp.server.fastmcp import FastMCP
+import uvicorn
 from uvicorn.config import LOGGING_CONFIG as UVICORN_LOGGING_CONFIG
+from starlette.middleware.cors import CORSMiddleware
 
 from academia_mcp.settings import settings
 from academia_mcp.tools.arxiv_search import arxiv_search
 from academia_mcp.tools.arxiv_download import arxiv_download
-from academia_mcp.tools.s2_citations import s2_get_citations, s2_get_references
+from academia_mcp.tools.s2 import (
+    s2_get_citations,
+    s2_get_references,
+    s2_corpus_id_from_arxiv_id,
+    s2_get_info,
+)
 from academia_mcp.tools.hf_datasets_search import hf_datasets_search
 from academia_mcp.tools.anthology_search import anthology_search
 from academia_mcp.tools.document_qa import document_qa
@@ -33,6 +40,8 @@ from academia_mcp.tools.bitflip import (
     score_research_proposals,
 )
 from academia_mcp.tools.review import review_pdf_paper, download_pdf_paper
+from academia_mcp.tools.show_image import show_image, describe_image
+from academia_mcp.tools.speech_to_text import speech_to_text
 
 
 def configure_uvicorn_style_logging(level: int = logging.INFO) -> None:
@@ -75,11 +84,14 @@ def run(
     server.add_tool(arxiv_download)
     server.add_tool(s2_get_citations)
     server.add_tool(s2_get_references)
+    server.add_tool(s2_corpus_id_from_arxiv_id)
+    server.add_tool(s2_get_info)
     server.add_tool(hf_datasets_search)
     server.add_tool(anthology_search)
     server.add_tool(get_latex_template)
     server.add_tool(get_latex_templates_list)
     server.add_tool(visit_webpage)
+    server.add_tool(show_image)
 
     if settings.WORKSPACE_DIR:
         server.add_tool(compile_latex)
@@ -107,19 +119,46 @@ def run(
         server.add_tool(generate_research_proposals)
         server.add_tool(score_research_proposals)
         server.add_tool(document_qa)
+        server.add_tool(describe_image)
         if settings.WORKSPACE_DIR:
             server.add_tool(review_pdf_paper)
     else:
         logger.warning("No OpenRouter API key is set, LLM-related tools will not be available!")
 
+    if settings.OPENAI_API_KEY:
+        server.add_tool(speech_to_text)
+    else:
+        logger.warning("No OpenAI API key is set, speech_to_text will not be available!")
+
     if port is None:
         if settings.PORT is not None:
             port = int(settings.PORT)
         else:
             port = find_free_port()
+
     server.settings.port = port
     server.settings.host = host
-    server.run(transport=transport)
+
+    if transport == "streamable-http":
+        # Enable CORS for browser-based clients
+        app = server.streamable_http_app()
+        app.add_middleware(
+            CORSMiddleware,
+            allow_origins=["*"],
+            allow_credentials=True,
+            allow_methods=["GET", "POST", "OPTIONS"],
+            allow_headers=["*"],
+            expose_headers=["mcp-session-id", "mcp-protocol-version"],
+            max_age=86400,
+        )
+        uvicorn.run(
+            app,
+            host=server.settings.host,
+            port=server.settings.port,
+            log_level=server.settings.log_level.lower(),
+        )
+    else:
+        server.run(transport=transport)
 
 
 if __name__ == "__main__":
